diff --git a/contrib/pageinspect/heapfuncs.c b/contrib/pageinspect/heapfuncs.c
index b7d75b0..d0c2886 100644
--- a/contrib/pageinspect/heapfuncs.c
+++ b/contrib/pageinspect/heapfuncs.c
@@ -229,11 +229,12 @@ heap_page_items(PG_FUNCTION_ARGS)
 			{
 				if (tuphdr->t_infomask & HEAP_HASNULL)
 				{
-					int	bits_len =
-						((tuphdr->t_infomask2 & HEAP_NATTS_MASK) / 8 + 1) * 8;
+					int			bits_len;
 
+					bits_len =
+						((tuphdr->t_infomask2 & HEAP_NATTS_MASK) / 8 + 1) * 8;
 					values[11] = CStringGetTextDatum(
-								 bits_to_text(tuphdr->t_bits, bits_len));
+									 bits_to_text(tuphdr->t_bits, bits_len));
 				}
 				else
 					nulls[11] = true;
diff --git a/src/backend/executor/execParallel.c b/src/backend/executor/execParallel.c
index bdc6b43..6df62a7 100644
--- a/src/backend/executor/execParallel.c
+++ b/src/backend/executor/execParallel.c
@@ -400,8 +400,8 @@ ExecInitParallelPlan(PlanState *planstate, EState *estate, int nworkers)
 	if (estate->es_instrument)
 	{
 		instrumentation_len =
-			offsetof(SharedExecutorInstrumentation, plan_node_id)
-			+ sizeof(int) * e.nnodes;
+			offsetof(SharedExecutorInstrumentation, plan_node_id) +
+			sizeof(int) * e.nnodes;
 		instrumentation_len = MAXALIGN(instrumentation_len);
 		instrument_offset = instrumentation_len;
 		instrumentation_len += sizeof(Instrumentation) * e.nnodes * nworkers;
@@ -513,7 +513,7 @@ ExecParallelRetrieveInstrumentation(PlanState *planstate,
 	/* Also store the per-worker detail. */
 	ibytes = instrumentation->num_workers * sizeof(Instrumentation);
 	planstate->worker_instrument =
-		palloc(offsetof(WorkerInstrumentation, instrument) + ibytes);
+		palloc(ibytes + offsetof(WorkerInstrumentation, instrument));
 	planstate->worker_instrument->num_workers = instrumentation->num_workers;
 	memcpy(&planstate->worker_instrument->instrument, instrument, ibytes);
 
diff --git a/src/backend/executor/nodeAgg.c b/src/backend/executor/nodeAgg.c
index 614b26b..0c1e4a3 100644
--- a/src/backend/executor/nodeAgg.c
+++ b/src/backend/executor/nodeAgg.c
@@ -3016,7 +3016,8 @@ build_pertrans_for_aggref(AggStatePerTrans pertrans,
 		Expr	   *transfnexpr;
 
 		/*
-		 * Set up infrastructure for calling the transfn
+		 * Set up infrastructure for calling the transfn.  Note that invtrans
+		 * is not needed here.
 		 */
 		build_aggregate_transfn_expr(inputTypes,
 									 numArguments,
@@ -3025,7 +3026,7 @@ build_pertrans_for_aggref(AggStatePerTrans pertrans,
 									 aggtranstype,
 									 aggref->inputcollid,
 									 aggtransfn,
-									 InvalidOid,	/* invtrans is not needed here */
+									 InvalidOid,
 									 &transfnexpr,
 									 NULL);
 		fmgr_info(aggtransfn, &pertrans->transfn);
diff --git a/src/backend/tsearch/spell.c b/src/backend/tsearch/spell.c
index 5f1a97e..f48664b 100644
--- a/src/backend/tsearch/spell.c
+++ b/src/backend/tsearch/spell.c
@@ -1338,9 +1338,10 @@ NIImportOOAffixes(IspellDict *Conf, const char *filename)
 			|| (sflaglen > 2 && Conf->flagMode == FM_LONG))
 			goto nextline;
 
-		/*
+		/*--------
 		 * Affix header. For example:
 		 * SFX \ N 1
+		 *--------
 		 */
 		if (fields_read == 4)
 		{
@@ -1350,9 +1351,10 @@ NIImportOOAffixes(IspellDict *Conf, const char *filename)
 			else
 				flagflags = 0;
 		}
-		/*
+		/*--------
 		 * Affix fields. For example:
-		 * SFX \   0	Y/L	[^Y]
+		 * SFX \   0	Y/L [^Y]
+		 *--------
 		 */
 		else
 		{
diff --git a/src/backend/tsearch/to_tsany.c b/src/backend/tsearch/to_tsany.c
index 3f69d74..d41f82c 100644
--- a/src/backend/tsearch/to_tsany.c
+++ b/src/backend/tsearch/to_tsany.c
@@ -311,7 +311,8 @@ pushval_morph(Datum opaque, TSQueryParserState state, char *strval, int lenval,
 				}
 			}
 
-			pos = prs.words[count].pos.pos; /* save current word's position */
+			/* save current word's position */
+			pos = prs.words[count].pos.pos;
 
 			/* Go through all variants obtained from this token */
 			cntvar = 0;
@@ -343,7 +344,11 @@ pushval_morph(Datum opaque, TSQueryParserState state, char *strval, int lenval,
 			}
 
 			if (cntpos)
-				pushOperator(state, data->qoperator, 1); /* distance may be useful */
+			{
+				/* distance may be useful */
+				pushOperator(state, data->qoperator, 1);
+			}
+
 			cntpos++;
 		}
 
diff --git a/src/backend/utils/adt/dbsize.c b/src/backend/utils/adt/dbsize.c
index 1db4acf..4ec2fed 100644
--- a/src/backend/utils/adt/dbsize.c
+++ b/src/backend/utils/adt/dbsize.c
@@ -817,11 +817,14 @@ pg_size_bytes(PG_FUNCTION_ARGS)
 		else if (pg_strcasecmp(strptr, "kb") == 0)
 			multiplier = (int64) 1024;
 		else if (pg_strcasecmp(strptr, "mb") == 0)
-			multiplier = (int64) 1024 * 1024;
+			multiplier = ((int64) 1024) * 1024;
+
 		else if (pg_strcasecmp(strptr, "gb") == 0)
-			multiplier = (int64) 1024 * 1024 * 1024;
+			multiplier = ((int64) 1024) * 1024 * 1024;
+
 		else if (pg_strcasecmp(strptr, "tb") == 0)
-			multiplier = (int64) 1024 * 1024 * 1024 * 1024;
+			multiplier = ((int64) 1024) * 1024 * 1024 * 1024;
+
 		else
 			ereport(ERROR,
 					(errcode(ERRCODE_INVALID_PARAMETER_VALUE),
diff --git a/src/backend/utils/adt/tsginidx.c b/src/backend/utils/adt/tsginidx.c
index 3f1e7f9..ebc11c9 100644
--- a/src/backend/utils/adt/tsginidx.c
+++ b/src/backend/utils/adt/tsginidx.c
@@ -222,9 +222,10 @@ TS_execute_ternary(GinChkVal *gcv, QueryItem *curitem)
 	check_stack_depth();
 
 	if (curitem->type == QI_VAL)
-		return checkcondition_gin_internal(gcv,
-										   (QueryOperand *) curitem,
-										   NULL /* don't have any position info */);
+		return
+			checkcondition_gin_internal(gcv,
+										(QueryOperand *) curitem,
+										NULL /* don't have position info */ );
 
 	switch (curitem->qoperator.oper)
 	{
diff --git a/src/backend/utils/adt/tsvector_op.c b/src/backend/utils/adt/tsvector_op.c
index d4fb0ff..8298e38 100644
--- a/src/backend/utils/adt/tsvector_op.c
+++ b/src/backend/utils/adt/tsvector_op.c
@@ -834,7 +834,8 @@ tsvector_filter(PG_FUNCTION_ARGS)
 				posvout->pos[npos++] = posvin->pos[k];
 		}
 
-		if (!npos) /* no satisfactory positions found, so skip that lexeme */
+		/* if no satisfactory positions found, skip lexeme */
+		if (!npos)
 			continue;
 
 		arrout[j].haspos = true;
